Module: Resourcerer::Controller

Extended by:
ActiveSupport::Concern
Defined in:
lib/resourcerer/controller.rb

Overview

Public: Provides two resource helper methods to simplify the definition and usage of Resources.

It’s also possible to define presets, which can then be reused by providing the :using option when using or defining a Resource.

Defined Under Namespace

Modules: ClassMethods

Instance Method Summary collapse

Instance Method Details

#resource(name, **options) ⇒ Object



19
20
21
# File 'lib/resourcerer/controller.rb', line 19

def resource(name, **options)
  Resource.new(self, name, **options).get(self)
end